@@ -80,15 +80,15 @@ export instdir=${srcdir}/.inst
 export srcinstdir=${srcdir}/.sinst
 export checkfile=${topdir}/${FULLPKG}.check
 
-export PATH=${srcdir}/.build/glib/.libs:${srcdir}/.build/gmodule/.libs:${srcdir}/.build/gobject/.libs:${srcdir}/.build/gthread/.libs:${srcdir}/.build/tests/.libs:${PATH}
+export PATH=${srcdir}/.build/glib/.libs:${srcdir}/.build/gmodule/.libs:${srcdir}/.build/gobject/.libs:${srcdir}/.build/gthread/.libs:${srcdir}/.build/tests/.libs:/usr/local/bin:/usr/bin:/bin:/usr/X11R6/bin
 
 prefix=/usr
 sysconfdir=/etc
 if [ -z "$MY_CFLAGS" ]; then
-  MY_CFLAGS="-O2"
+  MY_CFLAGS="-g0 -O3"
 fi
 if [ -z "$MY_CFLAGS" ]; then
-  MY_LDFLAGS=
+  MY_LDFLAGS="-Wl,-s"
 fi
 
 export install_docs="\
@@ -163,7 +163,7 @@ reconf() {
 }
 build() {
   (cd ${objdir} && \
-  CFLAGS="${MY_CFLAGS}" make )
+  CFLAGS="${MY_CFLAGS}" LDFLAGS="${MY_LDFLAGS}" make )
 }
 check() {
   (cd ${objdir} && \
